:orphan:

.. _api_documentation:

=================
API Documentation
=================

mne_bids
--------
:py:mod:`mne_bids`:

.. automodule:: mne_bids
   :no-members:
   :no-inherited-members:

.. currentmodule:: mne_bids

.. autosummary::
   :toctree: generated/

   write_raw_bids
   read_raw_bids
   write_meg_calibration
   write_meg_crosstalk
   BIDSPath
   make_dataset_description
   make_report
   write_anat
   mark_channels
   get_anat_landmarks
   update_anat_landmarks
   get_head_mri_trans
   convert_montage_to_mri
   convert_montage_to_ras
   template_to_head
   get_anonymization_daysback
   search_folder_for_text
   print_dir_tree
   get_bids_path_from_fname
   get_entities_from_fname
   get_entity_vals
   get_datatypes
   inspect_dataset
   update_sidecar_json
   anonymize_dataset

mne_bids.stats
--------------

:py:mod:`mne_bids.stats`:

.. automodule:: mne_bids.stats
   :no-members:
   :no-inherited-members:

.. currentmodule:: mne_bids.stats

.. autosummary::
   :toctree: generated/

   count_events


mne_bids.copyfiles
------------------

:py:mod:`mne_bids.copyfiles`:

.. automodule:: mne_bids.copyfiles
   :no-members:
   :no-inherited-members:

.. currentmodule:: mne_bids.copyfiles

.. autosummary::
   :toctree: generated/

   copyfile_brainvision
   copyfile_edf
   copyfile_eeglab
   copyfile_ctf
   copyfile_bti
   copyfile_kit
